function hermis(alt)

% Multi-compartmental Model of Hermissenda crassicornis photoreceptor B
% To run with default parameters, let alt = [1,1,1,1,1,1,1]


clf;
orient portrait;


%%%%%%%%%%%%%%%%%%%%%%%
% INITIALIZATION
%%%%%%%%%%%%%%%%%%%%%%%
DT = 0.025;  % ms
TMAX = 200;
global t;
global v;

vdot = 1;

t = 0:DT:TMAX;


% columns 2-7 are the compartments:
% Microvilli -> soma -> axon A, B, C -> terminal
% columns 1 and 8 are left blank as buffers

G = [0 0.483 0.0378 0.03 0.03 0.03 0.0347 0 ]; % Conductance between compartments in uS
SA = [0 0.0000157 0.00002827 0.00000785 0.00000785 0.00000785 0.00001021 0]; % surface area of membranes in cm^2

%VREST = -50.0;  % mA

GNA =  alt(1)*[0 0 0       0 0.02      0.02    0       0];	% S/cm^2
GH =   alt(2)*[0 0 0.008   0 0.02      0.02    0       0];	% S/cm^2
GKA =  alt(3)*[0 0 0       0 0.07      0.07    0       0]; 
GKV =  alt(4)*[0 0 0.12    0 0.12      0.12    0       0];
GCAS = alt(5)*[0 0 0.0015  0 0.0015    0.0015  0.0015  0];
GCAT = alt(6)*[0 0 0.00175 0 0.0015    0.0015  0.0015  0];
GKCA = alt(7)*[0 0 0.0004  0 0.0004    0.0004  0.0004  0];

GLEAK = [0 0.0002 0.0002 0.0004 0.0002 0.0002 0.0002 0];	% S/cm^2

ENA = 40;	% mV
EH = -29.4;
EKA = -65;
EKV = -65;
ECAS = 80;
ECAT = 70;
EKCA = -80;

ELEAK = [0 -78 -98 -78 -78 -78 -78 0];

C_M = ones(1,8)*1;	% uF/cm^2

record = ones(1,8);

   
   %%%%%%%%%%%%%%%%%%%%%%%
   % MAIN SIMULATION LOOP
   %%%%%%%%%%%%%%%%%%%%%%%
   
   v = [0  -0.5  -26.4  -31.3  -30.3  -30.  -23.7  0];					% initial membrane voltage for the six compartments
   
    SS_A_NA = 1./(1+ exp(-(v+22)/5.5)); % calculating steady state of A
    TC_A_NA = 0.00015 + 0.00085./(1+exp((v+12)/4.5)); % time constant for A in seconds
    SS_B_NA = 1./(1+ exp((v+30)/9.2));
    TC_B_NA = ones(1,8) .* 0.06; % seconds
    SS_A_H  = 1./(1+exp((v+75.14)/7));
    TC_A_H  = 0.05 + 0.95 ./(1+exp(-(v+64)/14.4))./(1+exp(v-25/6));
    SS_A_KA = 1./(1+exp(-(v+5)/10));
    TC_A_KA = 0.002 + 0.031./(1+exp(v/5.9)).^2;
    SS_B_KA = 0.0125 + 0.9875./(1+exp((v+56)./8.37));
    TC_B_KA = ones(1,8) .* 0.13;
    SS_A_KV = 1./(1+exp(-(v+5)./12.5));
    TC_A_KV = 0.012 + 0.048./(1+exp((v+3.5)./8)).^2;
    SS_B_KV = 0.285 + 0.715./(1+exp((v+57)./12));
    TC_B_KV = 0.15 + 0.35./(1+exp(-(v+4)/3))./(1+exp((v-7)./12));
    SS_A_CAS = 1./(1+exp(-(v+2)/11));
    TC_A_CAS = 0.06 + 0.74./(1+exp(-(v-75)/53))./(1+exp((v-25)./6));
    SS_B_CAS = 0.99 + 0.01./(1+exp((v-6.3)));
    TC_B_CAS = ones(1,8) .* 3;
    SS_A_CAT = 1./(1+exp(-(v+42)./12));
    TC_A_CAT = ones(1,8) .* 0.0044;
    SS_B_CAT = 1./(1+exp((v+40)./10.15));
    TC_B_CAT = 0.075 + 0.525./(1+exp((v+10)./5));
   
   
    a_na  = SS_A_NA;
    b_na  = SS_B_NA;
    a_h   = SS_A_H;
    a_ka  = SS_A_KA;
    b_ka  = SS_B_KA;
    a_kv  = SS_A_KV;
    b_kv  = SS_B_KV;
    a_cas = SS_A_CAS;
    b_cas = SS_B_CAS;
    a_cat = SS_A_CAT;
    b_cat = SS_B_CAT;
    maxm = -200;
    
    C_Ca = ones(1,8) * 0; % calcium concentration
    fBr = C_Ca ./ (100+C_Ca);

   
   for i=2:length(t)
      V = v(i-1,1:8);
       
      InjectList = [0 0 50 0 0 0 0 0];
      gNA = GNA    .* a_na(i-1,1:8).^3 .* b_na(i-1,1:8);   % S/cm^2
      gH  = GH     .* a_h(i-1,1:8);
      gKA = GKA    .* a_ka(i-1,1:8) .* b_ka(i-1,1:8);
      gKV = GKV    .* a_kv(i-1,1:8).^2 .* b_kv(i-1,1:8);
      gCAS = GCAS  .* a_cas(i-1,1:8) .* b_cas(i-1,1:8);
      gCAT = GCAT  .* a_cat(i-1,1:8).^3 .* b_cat(i-1,1:8);
      
      % Record ion currents       
      ina(i,1:8) = -gNA.*(V-ENA); % S * mV
      ih(i,1:8) = -gH.*(V-EH);
      ika(i,1:8) = -(gKA.*(V-EKA));
      ikv(i,1:8) = -gKV.*(V-EKV);
      icas(i,1:8) = -gCAS.*(V-ECAS);
      icat(i,1:8) = -gCAT.*(V-ECAT);
      ikca(i,1:8) = GKCA.*fBr.*(V-EKCA);
      
      ileak = GLEAK.* SA .*(V-ELEAK);
          fprintf('%g\n', i);       
        for comp=2:7 
            
 
          I = InjectList(comp) * (i>6000 & i<7000);  
          vdot = (I - 1000*gNA(comp).*(V(comp)-ENA) - 1000*gH(comp).*(V(comp)-EH)- 1000*GLEAK(comp).*(V(comp)-ELEAK(comp)));       % current from channels
          vdot = vdot - (1000*gKA(comp).*(V(comp)-EKA) + 1000*gKV(comp).*(V(comp)-EKV) + 1000*gCAS(comp).*(V(comp)-ECAS));  % if a compartment doesn't have a specific channel, the conductance 
          vdot = vdot - (1000*gCAT(comp)*(V(comp)-ECAT) + ikca(comp));                                                          % for that channel has been defined as zero. 
          
          
          vdot = vdot + ((G(comp)*(V(comp-1)-V(comp))) + SA(comp)*G(comp+1).*(V(comp+1)- V(comp)))/(1000*SA(comp));               %current from adjacent compartments                                        


          v(i,comp) = v(i-1,comp) + vdot*DT;		% Euler integration
          

          
          %fprintf('%g ',max);
          record(i,comp) = vdot;
        end
       
          if(i == 6000)
             base = v(i-1,7);
          end
          
          if(i > 6000) && (v(i-1,7) > maxm)
              maxm = v(i-1,7);
              tmax = i-1;
          end
              
        
        %fprintf('%g', SS_A_NA);
        %fprintf('\n');
    SS_A_NA = 1./(1+ exp(-(V+22)/5.5));               % calculating steady state of A
    TC_A_NA = 0.00015 + 0.00085./(1+exp((V+12)/4.5)); % time constant for A in seconds
    SS_B_NA = 1./(1+ exp((V+30)/9.2));
    TC_B_NA = 0.06; % seconds
    SS_A_H  = 1./(1+exp(-(V+75.14)/7));
    TC_A_H  = 0.05 + 0.95 ./(1+exp(-(V+64)/14.4))./(1+exp(V-25/6));
    SS_A_KA = 1./(1+exp(-(V+5)/10));
    TC_A_KA = 0.002 + 0.031./(1+exp(V/5.9)).^2;
    SS_B_KA = 0.0125 + 0.9875./(1+exp((V+56)./8.37));
    TC_B_KA = 0.13;
    SS_A_KV = 1./(1+exp(-(V+5)./12.5));
    TC_A_KV = 0.012 + 0.048./(1+exp((V+3.5)./8)).^2;
    SS_B_KV = 0.285 + 0.715./(1+exp((V+57)./12));
    TC_B_KV = 0.15 + 0.35./(1+exp(-(V+4)/3))./(1+exp((V-7)./12));
    SS_A_CAS = 1./(1+exp(-(V+2)/11));
    TC_A_CAS = 0.06 + 0.74./(1+exp(-(V-75)/53))./(1+exp((V-25)./6));
    SS_B_CAS = 0.99 + 0.01./(1+exp((V-6.3)));
    TC_B_CAS = 3;
    SS_A_CAT = 1./(1+exp(-(V+42)./12));
    TC_A_CAT = 0.0044;
    SS_B_CAT = 1./(1+exp((V+40)./10.15));
    TC_B_CAT = 0.075 + 0.525./(1+exp((V+10)./5));
    
    dot_A_NA =  (SS_A_NA-a_na(i-1,1:8))  ./(1000*TC_A_NA);  % ms^-1
    dot_B_NA =  (SS_B_NA-b_na(i-1,1:8))  ./(1000*TC_B_NA);
    dot_A_H =   (SS_A_H-a_h(i-1,1:8))    ./(1000*TC_A_H);
    dot_A_KA =  (SS_A_KA-a_ka(i-1,1:8))  ./(1000*TC_A_KA);
    dot_B_KA =  (SS_B_KA-b_ka(i-1,1:8))  ./(1000*TC_B_KA);
    dot_A_KV =  (SS_A_KV-a_kv(i-1,1:8))  ./(1000*TC_A_KV);
    dot_B_KV =  (SS_B_KV-b_kv(i-1,1:8))  ./(1000*TC_B_KV);
    dot_A_CAS = (SS_A_CAS-a_cas(i-1,1:8))./(1000*TC_A_CAS);
    dot_B_CAS = (SS_B_CAS-b_cas(i-1,1:8))./(1000*TC_B_CAS);
    dot_A_CAT = (SS_A_CAT-a_cat(i-1,1:8))./(1000*TC_A_CAT);
    dot_B_CAT = (SS_B_CAT-b_cat(i-1,1:8))./(1000*TC_B_CAT);
    
    a_na(i,1:8) = a_na(i-1,1:8) + dot_A_NA.*DT;
    b_na(i,1:8) = b_na(i-1,1:8)+dot_B_NA.*DT;
    a_h(i,1:8)  = a_h(i-1,1:8)+dot_A_H.*DT;
    a_ka(i,1:8) = a_ka(i-1,1:8) + dot_A_KA.*DT;
    b_ka(i,1:8) = b_ka(i-1,1:8)+dot_B_KA.*DT;
    a_kv(i,1:8) = a_kv(i-1,1:8) + dot_A_KV.*DT;
    b_kv(i,1:8) = b_kv(i-1,1:8)+dot_B_KV.*DT;
    a_cas(i,1:8) = a_cas(i-1,1:8)+dot_A_CAS.*DT;
    b_cas(i,1:8) = b_cas(i-1,1:8)+dot_B_CAS.*DT;
    a_cat(i,1:8) = a_cat(i-1,1:8) + dot_A_CAT.*DT;
    b_cat(i,1:8) = b_cat(i-1,1:8)+dot_B_CAT.*DT;
    
    dot_C_Ca = 0.7 * (140 *(icas(i,1:8)+icat(i,1:8)) - C_Ca);
    C_Ca = C_Ca + dot_C_Ca.*(DT/1000);
    fBr = C_Ca ./ (100 + C_Ca);

        
   end
   
%makegraph(v);


end
